@@ -172,8 +172,11 @@ def _getversion(dictionary):
             if 'min' in chdict or 'max' in chdict:
                 return 1
     else:
-        return dictionary['version']
-    return 0
+        v = dictionary['version']
+        if not isinstance(v, int) or v < 1 or v > SPEC_VERSION:
+            return 0
+        return v
+    return SPEC_VERSION
 
 
 class ChannelObject(object):
@@ -488,21 +491,26 @@ class RenderControl(BaseControl):
         """ Implements the 'info' command """
         first = True
         for img in self.render_images(self.gateway, args.object, batch=1):
-            ro = RenderObject(img)
-            if args.style == 'plain':
-                self.ctx.out(str(ro))
-            elif args.style == 'yaml':
-                self.ctx.out(yaml.dump(ro.to_dict(), explicit_start=True,
-                             width=80, indent=4,
-                             default_flow_style=False).rstrip())
-            else:
-                if not first:
-                    self.ctx.die(
-                        103,
-                        "Output styles not supported for multiple images")
-                self.ctx.out(json.dumps(
-                    ro.to_dict(), sort_keys=True, indent=4))
-                first = False
+            try:
+                ro = RenderObject(img)
+                if args.style == 'plain':
+                    self.ctx.out(str(ro))
+                elif args.style == 'yaml':
+                    self.ctx.out(yaml.dump(ro.to_dict(), explicit_start=True,
+                                           width=80, indent=4,
+                                           default_flow_style=False).rstrip())
+                else:
+                    if not first:
+                        self.ctx.die(
+                            103,
+                            "Output styles not supported for multiple images")
+                    self.ctx.out(json.dumps(
+                        ro.to_dict(), sort_keys=True, indent=4))
+                    first = False
+            except Exception as e:
+                self.ctx.err('ERROR: %s' % e)
+            finally:
+                img._closeRE()
 
     @gateway_required
     def copy(self, args):
@@ -538,10 +546,10 @@ class RenderControl(BaseControl):
             self._update_channel_names(self, iids, namedict)
 
     def _update_channel_names(self, gateway, iids, namedict):
-            counts = gateway.setChannelNames("Image", iids, namedict)
-            if counts:
-                self.ctx.dbg("Updated channel names for %d/%d images" % (
-                    counts['updateCount'], counts['imageCount']))
+        counts = gateway.setChannelNames("Image", iids, namedict)
+        if counts:
+            self.ctx.dbg("Updated channel names for %d/%d images" % (
+                counts['updateCount'], counts['imageCount']))
 
     def _generate_thumbs(self, images):
         for img in images:
@@ -670,7 +678,8 @@ class RenderControl(BaseControl):
                         active_channels.append(ci)
 
             img.set_active_channels(
-                cindices, windows=rangelist, colors=colourlist)
+                cindices, windows=rangelist, colors=colourlist,
+                set_inactive=True)
 
             if greyscale is not None:
                 if greyscale:
